@@ -13,88 +13,148 @@ use twilight_model::{
 
 impl InMemoryCache {
     fn cache_guild(&self, guild: Guild) {
+        let Guild {
+            afk_channel_id,
+            afk_timeout,
+            application_id,
+            approximate_member_count: _,
+            approximate_presence_count: _,
+            banner,
+            channels,
+            default_message_notifications,
+            description,
+            discovery_splash,
+            emojis,
+            explicit_content_filter,
+            features,
+            icon,
+            id,
+            joined_at,
+            large,
+            max_members,
+            max_presences,
+            max_video_channel_users,
+            member_count,
+            members,
+            mfa_level,
+            name,
+            nsfw_level,
+            owner_id,
+            owner,
+            permissions,
+            preferred_locale,
+            premium_progress_bar_enabled,
+            premium_subscription_count,
+            premium_tier,
+            presences,
+            roles,
+            rules_channel_id,
+            splash,
+            stage_instances,
+            stickers,
+            system_channel_flags,
+            system_channel_id,
+            threads,
+            unavailable,
+            vanity_url_code,
+            verification_level,
+            voice_states,
+            widget_channel_id,
+            widget_enabled,
+        } = guild;
+
         // The map and set creation needs to occur first, so caching states and
         // objects always has a place to put them.
         if self.wants(ResourceType::CHANNEL) {
-            self.guild_channels.insert(guild.id, HashSet::new());
-            self.cache_guild_channels(guild.id, guild.channels);
-            self.cache_guild_channels(guild.id, guild.threads);
+            self.guild_channels.insert(id, HashSet::new());
+
+            let mut channels = channels;
+            let mut threads = threads;
+
+            for channel in &mut channels {
+                channel.guild_id = Some(id);
+            }
+
+            for channel in &mut threads {
+                channel.guild_id = Some(id);
+            }
+
+            self.cache_channels(channels);
+            self.cache_channels(threads);
         }
 
         if self.wants(ResourceType::EMOJI) {
-            self.guild_emojis.insert(guild.id, HashSet::new());
-            self.cache_emojis(guild.id, guild.emojis);
+            self.guild_emojis.insert(id, HashSet::new());
+            self.cache_emojis(id, emojis);
         }
 
         if self.wants(ResourceType::MEMBER) {
-            self.guild_members.insert(guild.id, HashSet::new());
-            self.cache_members(guild.id, guild.members);
+            self.guild_members.insert(id, HashSet::new());
+            self.cache_members(id, members);
         }
 
         if self.wants(ResourceType::PRESENCE) {
-            self.guild_presences.insert(guild.id, HashSet::new());
-            self.cache_presences(
-                guild.id,
-                guild.presences.into_iter().map(CachedPresence::from),
-            );
+            self.guild_presences.insert(id, HashSet::new());
+            self.cache_presences(id, presences.into_iter().map(CachedPresence::from));
         }
 
         if self.wants(ResourceType::ROLE) {
-            self.guild_roles.insert(guild.id, HashSet::new());
-            self.cache_roles(guild.id, guild.roles);
+            self.guild_roles.insert(id, HashSet::new());
+            self.cache_roles(id, roles);
         }
 
         if self.wants(ResourceType::STICKER) {
-            self.guild_stage_instances.insert(guild.id, HashSet::new());
-            self.cache_stickers(guild.id, guild.stickers);
+            self.guild_stage_instances.insert(id, HashSet::new());
+            self.cache_stickers(id, stickers);
         }
 
         if self.wants(ResourceType::VOICE_STATE) {
-            self.voice_state_guilds.insert(guild.id, HashSet::new());
-            self.cache_voice_states(guild.voice_states);
+            self.voice_state_guilds.insert(id, HashSet::new());
+            self.cache_voice_states(voice_states);
         }
 
         if self.wants(ResourceType::STAGE_INSTANCE) {
-            self.guild_stage_instances.insert(guild.id, HashSet::new());
-            self.cache_stage_instances(guild.id, guild.stage_instances);
+            self.guild_stage_instances.insert(id, HashSet::new());
+            self.cache_stage_instances(id, stage_instances);
         }
 
         let guild = CachedGuild {
-            id: guild.id,
-            afk_channel_id: guild.afk_channel_id,
-            afk_timeout: guild.afk_timeout,
-            application_id: guild.application_id,
-            banner: guild.banner,
-            default_message_notifications: guild.default_message_notifications,
-            description: guild.description,
-            discovery_splash: guild.discovery_splash,
-            explicit_content_filter: guild.explicit_content_filter,
-            features: guild.features,
-            icon: guild.icon,
-            joined_at: guild.joined_at,
-            large: guild.large,
-            max_members: guild.max_members,
-            max_presences: guild.max_presences,
-            member_count: guild.member_count,
-            mfa_level: guild.mfa_level,
-            name: guild.name,
-            nsfw_level: guild.nsfw_level,
-            owner: guild.owner,
-            owner_id: guild.owner_id,
-            permissions: guild.permissions,
-            preferred_locale: guild.preferred_locale,
-            premium_progress_bar_enabled: guild.premium_progress_bar_enabled,
-            premium_subscription_count: guild.premium_subscription_count,
-            premium_tier: guild.premium_tier,
-            rules_channel_id: guild.rules_channel_id,
-            splash: guild.splash,
-            system_channel_id: guild.system_channel_id,
-            system_channel_flags: guild.system_channel_flags,
-            unavailable: guild.unavailable,
-            verification_level: guild.verification_level,
-            vanity_url_code: guild.vanity_url_code,
-            widget_channel_id: guild.widget_channel_id,
-            widget_enabled: guild.widget_enabled,
+            id,
+            afk_channel_id,
+            afk_timeout,
+            application_id,
+            banner,
+            default_message_notifications,
+            description,
+            discovery_splash,
+            explicit_content_filter,
+            features,
+            icon,
+            joined_at,
+            large,
+            max_members,
+            max_presences,
+            max_video_channel_users,
+            member_count,
+            mfa_level,
+            name,
+            nsfw_level,
+            owner,
+            owner_id,
+            permissions,
+            preferred_locale,
+            premium_progress_bar_enabled,
+            premium_subscription_count,
+            premium_tier,
+            rules_channel_id,
+            splash,
+            system_channel_id,
+            system_channel_flags,
+            unavailable,
+            verification_level,
+            vanity_url_code,
+            widget_channel_id,
+            widget_enabled,
         };
 
         self.unavailable_guilds.remove(&guild.id());
@@ -127,7 +187,7 @@ impl InMemoryCache {
         }
 
         if self.wants(ResourceType::CHANNEL) {
-            remove_ids(&self.guild_channels, &self.channels_guild, id);
+            remove_ids(&self.guild_channels, &self.channels, id);
         }
 
         if self.wants(ResourceType::EMOJI) {
@@ -226,8 +286,8 @@ mod tests {
     use crate::test;
     use twilight_model::{
         channel::{
-            thread::{AutoArchiveDuration, PublicThread, ThreadMember, ThreadMetadata},
-            ChannelType, GuildChannel, TextChannel,
+            thread::{AutoArchiveDuration, ThreadMember, ThreadMetadata},
+            Channel, ChannelType,
         },
         datetime::{Timestamp, TimestampParseError},
         gateway::payload::incoming::{MemberAdd, MemberRemove, UnavailableGuild},
@@ -244,41 +304,47 @@ mod tests {
 
         let timestamp = Timestamp::from_str(DATETIME)?;
 
-        let channels = Vec::from([GuildChannel::Text(TextChannel {
-            id: Id::new(111),
+        let channels = Vec::from([Channel {
+            application_id: None,
+            bitrate: None,
+            default_auto_archive_duration: None,
             guild_id: None,
+            icon: None,
+            id: Id::new(111),
+            invitable: None,
             kind: ChannelType::GuildText,
             last_message_id: None,
             last_pin_timestamp: None,
-            name: "guild channel with no guild id".to_owned(),
-            nsfw: true,
-            permission_overwrites: Vec::new(),
-            parent_id: None,
-            position: 1,
-            rate_limit_per_user: None,
-            topic: None,
-        })]);
-
-        let threads = Vec::from([GuildChannel::PublicThread(PublicThread {
-            id: Id::new(222),
-            default_auto_archive_duration: None,
-            guild_id: None,
-            kind: ChannelType::GuildPublicThread,
-            last_message_id: None,
-            message_count: 0,
-            name: "guild thread with no guild id".to_owned(),
+            member: None,
+            member_count: None,
+            message_count: None,
+            name: Some("guild channel with no guild id".to_owned()),
+            newly_created: None,
+            nsfw: Some(true),
             owner_id: None,
             parent_id: None,
+            permission_overwrites: Some(Vec::new()),
+            position: Some(1),
             rate_limit_per_user: None,
-            member_count: 0,
-            thread_metadata: ThreadMetadata {
-                archived: false,
-                auto_archive_duration: AutoArchiveDuration::Hour,
-                archive_timestamp: timestamp,
-                create_timestamp: Some(timestamp),
-                invitable: None,
-                locked: false,
-            },
+            recipients: None,
+            rtc_region: None,
+            thread_metadata: None,
+            topic: None,
+            user_limit: None,
+            video_quality_mode: None,
+        }]);
+
+        let threads = Vec::from([Channel {
+            application_id: None,
+            bitrate: None,
+            default_auto_archive_duration: None,
+            guild_id: None,
+            icon: None,
+            id: Id::new(222),
+            invitable: None,
+            kind: ChannelType::GuildPublicThread,
+            last_message_id: None,
+            last_pin_timestamp: None,
             member: Some(ThreadMember {
                 flags: 0,
                 id: Some(Id::new(1)),
@@ -287,7 +353,30 @@ mod tests {
                 presence: None,
                 user_id: Some(Id::new(2)),
             }),
-        })]);
+            member_count: Some(0),
+            message_count: Some(0),
+            name: Some("guild thread with no guild id".to_owned()),
+            newly_created: None,
+            nsfw: None,
+            owner_id: None,
+            parent_id: None,
+            permission_overwrites: None,
+            position: None,
+            rate_limit_per_user: None,
+            recipients: None,
+            rtc_region: None,
+            thread_metadata: Some(ThreadMetadata {
+                archived: false,
+                auto_archive_duration: AutoArchiveDuration::Hour,
+                archive_timestamp: timestamp,
+                create_timestamp: Some(timestamp),
+                invitable: None,
+                locked: false,
+            }),
+            topic: None,
+            user_limit: None,
+            video_quality_mode: None,
+        }]);
 
         let guild = Guild {
             id: Id::new(123),
@@ -342,27 +431,16 @@ mod tests {
         let cache = InMemoryCache::new();
         cache.cache_guild(guild);
 
-        let channel = cache.guild_channel(Id::new(111)).unwrap();
+        let channel = cache.channel(Id::new(111)).unwrap();
 
-        let thread = cache.guild_channel(Id::new(222)).unwrap();
+        let thread = cache.channel(Id::new(222)).unwrap();
 
         // The channel was given to the cache without a guild ID, but because
         // it's part of a guild create, the cache can automatically attach the
         // guild ID to it. So now, the channel's guild ID is present with the
         // correct value.
-        match channel.resource() {
-            GuildChannel::Text(c) => {
-                assert_eq!(Some(Id::new(123)), c.guild_id);
-            }
-            _ => panic!("{:?}", channel),
-        }
-
-        match thread.resource() {
-            GuildChannel::PublicThread(c) => {
-                assert_eq!(Some(Id::new(123)), c.guild_id);
-            }
-            _ => panic!("{:?}", channel),
-        }
+        assert_eq!(Some(Id::new(123)), channel.guild_id);
+        assert_eq!(Some(Id::new(123)), thread.guild_id);
 
         Ok(())
     }
