@@ -2,11 +2,14 @@ use crate::{config::ResourceType, InMemoryCache, UpdateCache};
 use twilight_model::{
     gateway::payload::incoming::{IntegrationCreate, IntegrationDelete, IntegrationUpdate},
     guild::GuildIntegration,
-    id::{GuildId, IntegrationId},
+    id::{
+        marker::{GuildMarker, IntegrationMarker},
+        Id,
+    },
 };
 
 impl InMemoryCache {
-    fn cache_integration(&self, guild_id: GuildId, integration: GuildIntegration) {
+    fn cache_integration(&self, guild_id: Id<GuildMarker>, integration: GuildIntegration) {
         self.guild_integrations
             .entry(guild_id)
             .or_default()
@@ -20,7 +23,7 @@ impl InMemoryCache {
         );
     }
 
-    fn delete_integration(&self, guild_id: GuildId, integration_id: IntegrationId) {
+    fn delete_integration(&self, guild_id: Id<GuildMarker>, integration_id: Id<IntegrationMarker>) {
         if self
             .integrations
             .remove(&(guild_id, integration_id))
