@@ -2,17 +2,24 @@ use crate::{config::ResourceType, InMemoryCache, UpdateCache};
 use twilight_model::{
     gateway::payload::incoming::{RoleCreate, RoleDelete, RoleUpdate},
     guild::Role,
-    id::{GuildId, RoleId},
+    id::{
+        marker::{GuildMarker, RoleMarker},
+        Id,
+    },
 };
 
 impl InMemoryCache {
-    pub(crate) fn cache_roles(&self, guild_id: GuildId, roles: impl IntoIterator<Item = Role>) {
+    pub(crate) fn cache_roles(
+        &self,
+        guild_id: Id<GuildMarker>,
+        roles: impl IntoIterator<Item = Role>,
+    ) {
         for role in roles {
             self.cache_role(guild_id, role);
         }
     }
 
-    fn cache_role(&self, guild_id: GuildId, role: Role) {
+    fn cache_role(&self, guild_id: Id<GuildMarker>, role: Role) {
         // Insert the role into the guild_roles map
         self.guild_roles
             .entry(guild_id)
@@ -23,7 +30,7 @@ impl InMemoryCache {
         crate::upsert_guild_item(&self.roles, guild_id, role.id, role);
     }
 
-    fn delete_role(&self, role_id: RoleId) {
+    fn delete_role(&self, role_id: Id<RoleMarker>) {
         if let Some((_, role)) = self.roles.remove(&role_id) {
             if let Some(mut roles) = self.guild_roles.get_mut(&role.guild_id) {
                 roles.remove(&role_id);
@@ -72,25 +79,15 @@ mod tests {
         let cache = InMemoryCache::new();
 
         cache.update(&RoleCreate {
-            guild_id: GuildId::new(1).expect("non zero"),
-            role: test::role(RoleId::new(2).expect("non zero")),
+            guild_id: Id::new(1),
+            role: test::role(Id::new(2)),
         });
 
         {
-            assert_eq!(
-                1,
-                cache
-                    .guild_roles
-                    .get(&GuildId::new(1).expect("non zero"))
-                    .unwrap()
-                    .len()
-            );
+            assert_eq!(1, cache.guild_roles.get(&Id::new(1)).unwrap().len());
             assert_eq!(1, cache.roles.len());
 
-            assert_eq!(
-                "test".to_string(),
-                cache.role(RoleId::new(2).expect("non zero")).unwrap().name
-            );
+            assert_eq!("test".to_string(), cache.role(Id::new(2)).unwrap().name);
         }
     }
 
@@ -101,9 +98,7 @@ mod tests {
         // Single inserts
         {
             // The role ids for the guild with id 1
-            let guild_1_role_ids = (1..=10)
-                .map(|n| RoleId::new(n).expect("non zero"))
-                .collect::<Vec<_>>();
+            let guild_1_role_ids = (1..=10).map(Id::new).collect::<Vec<_>>();
             // Map the role ids to a test role
             let guild_1_roles = guild_1_role_ids
                 .iter()
@@ -112,13 +107,11 @@ mod tests {
                 .collect::<Vec<_>>();
             // Cache all the roles using cache role
             for role in guild_1_roles.clone() {
-                cache.cache_role(GuildId::new(1).expect("non zero"), role);
+                cache.cache_role(Id::new(1), role);
             }
 
             // Check for the cached guild role ids
-            let cached_roles = cache
-                .guild_roles(GuildId::new(1).expect("non zero"))
-                .unwrap();
+            let cached_roles = cache.guild_roles(Id::new(1)).unwrap();
             assert_eq!(cached_roles.len(), guild_1_role_ids.len());
             assert!(guild_1_role_ids.iter().all(|id| cached_roles.contains(id)));
 
@@ -133,9 +126,7 @@ mod tests {
         // Bulk inserts
         {
             // The role ids for the guild with id 2
-            let guild_2_role_ids = (101..=110)
-                .map(|n| RoleId::new(n).expect("non zero"))
-                .collect::<Vec<_>>();
+            let guild_2_role_ids = (101..=110).map(Id::new).collect::<Vec<_>>();
             // Map the role ids to a test role
             let guild_2_roles = guild_2_role_ids
                 .iter()
@@ -143,12 +134,10 @@ mod tests {
                 .map(test::role)
                 .collect::<Vec<_>>();
             // Cache all the roles using cache roles
-            cache.cache_roles(GuildId::new(2).expect("non zero"), guild_2_roles.clone());
+            cache.cache_roles(Id::new(2), guild_2_roles.clone());
 
             // Check for the cached guild role ids
-            let cached_roles = cache
-                .guild_roles(GuildId::new(2).expect("non zero"))
-                .unwrap();
+            let cached_roles = cache.guild_roles(Id::new(2)).unwrap();
             assert_eq!(cached_roles.len(), guild_2_role_ids.len());
             assert!(guild_2_role_ids.iter().all(|id| cached_roles.contains(id)));
 
