@@ -9,10 +9,11 @@ impl InMemoryCache {
     }
 
     fn cache_voice_state(&self, voice_state: VoiceState) {
-        // This should always exist, but just in case use a match
-        let guild_id = match voice_state.guild_id {
-            Some(id) => id,
-            None => return,
+        // This should always exist, but let's check just in case.
+        let guild_id = if let Some(id) = voice_state.guild_id {
+            id
+        } else {
+            return;
         };
 
         let user_id = voice_state.user_id;
