@@ -6,6 +6,14 @@
 //! [`twilight-rs`] ecosystem. It's responsible for processing events and
 //! caching things like guilds, channels, users, and voice states.
 //!
+//! ## Statistics
+//!
+//! Statistics can be an important debugging tool for determining how large a
+//! cache is or determining whether a cache has an expected amount of resources
+//! within it. An interface for retrieving statistics about the amount of a
+//! resource within the cache as a whole or on a guild-level can be retrieved
+//! via [`InMemoryCache::stats`].
+//!
 //! ## Features
 //!
 //! By default no feature is enabled.
@@ -759,10 +767,7 @@ impl InMemoryCache {
         guild_id: Id<GuildMarker>,
         user_id: Id<UserMarker>,
     ) -> Option<Id<RoleMarker>> {
-        let member = match self.members.get(&(guild_id, user_id)) {
-            Some(member) => member,
-            None => return None,
-        };
+        let member = self.members.get(&(guild_id, user_id))?;
 
         let mut highest_role: Option<(i64, Id<RoleMarker>)> = None;
 
